@@ -30,7 +30,6 @@ import pandas as pd
 
 from .SignalAnalysis.tears import portfolio_construction
 
-
 _OPTIMIZER_RETURN_FIELDS = [
     'trade_volume',
     'trade_value',
@@ -73,11 +72,18 @@ def ideal(
     """
     if not print_validate_factor_frame(factor_frame):
         return
+
+    tickers = factor_frame.columns.values
+    if len(tickers[0]) > 6:
+        tickers_new = [ticker[:6] for ticker in tickers]
+        factor_frame.columns = tickers_new
+
     # 宽格式转换为长格式
     factor_value_frame = factor_frame.copy()
     factor_value_frame.index.name = 'date'
     factor_value_frame.reset_index(inplace=True)
     factor_value_frame = pd.melt(factor_value_frame, id_vars=['date'], var_name='ticker', value_name='value')
+    factor_value_frame['date'] = factor_value_frame['date'].apply(lambda x: x.replace('-', ''))
 
     result = portfolio_construction(
         factor_value_frame=factor_value_frame,
@@ -122,11 +128,18 @@ def long_only(
     """
     if not print_validate_factor_frame(factor_frame):
         return
+
+    tickers = factor_frame.columns.values
+    if len(tickers[0]) > 6:
+        tickers_new = [ticker[:6] for ticker in tickers]
+        factor_frame.columns = tickers_new
+
     # 宽格式转换为长格式
     factor_value_frame = factor_frame.copy()
     factor_value_frame.index.name = 'date'
     factor_value_frame.reset_index(inplace=True)
     factor_value_frame = pd.melt(factor_value_frame, id_vars=['date'], var_name='ticker', value_name='value')
+    factor_value_frame['date'] = factor_value_frame['date'].apply(lambda x: x.replace('-', ''))
 
     result = portfolio_construction(
         factor_value_frame=factor_value_frame,
@@ -175,11 +188,18 @@ def long_short(
     """
     if not print_validate_factor_frame(factor_frame):
         return
+
+    tickers = factor_frame.columns.values
+    if len(tickers[0]) > 6:
+        tickers_new = [ticker[:6] for ticker in tickers]
+        factor_frame.columns = tickers_new
+
     # 宽格式转换为长格式
     factor_value_frame = factor_frame.copy()
     factor_value_frame.index.name = 'date'
     factor_value_frame.reset_index(inplace=True)
     factor_value_frame = pd.melt(factor_value_frame, id_vars=['date'], var_name='ticker', value_name='value')
+    factor_value_frame['date'] = factor_value_frame['date'].apply(lambda x: x.replace('-', ''))
 
     result = portfolio_construction(
         factor_value_frame=factor_value_frame,
@@ -209,9 +229,9 @@ def limit_active_risk(
         target_risk=0.3, target_turnover=None, fee=0, init_cash=1e8, init_holding=None,
         asset_lower_boundary=0, asset_upper_boundary=1,
         asset_cons_method='absolute', asset_cons_type='by_value',
-        factor_exposure_lower_boundary=0, factor_exposure_upper_boundary=0,
-        sector_exposure_lower_boundary=0, sector_exposure_upper_boundary=0,
-        risk_aversion=0, soft_params=pd.DataFrame()
+        factor_exposure_lower_boundary=-10, factor_exposure_upper_boundary=10,
+        sector_exposure_lower_boundary=-10, sector_exposure_upper_boundary=10,
+        risk_aversion=0, soft_params=None, cash_boundary=None
 ):
     """
     :param factor_frame:
@@ -234,24 +254,36 @@ def limit_active_risk(
     :param asset_upper_boundary: float/Series，个股仓位上限，默认为1
     :param asset_cons_method: str， 资产上下界约束方法，支持选择'absolute'/'active'：绝对权重约束/主动权重约束
     :param asset_cons_type: str， 资产主动权重约束类型，支持选择'by_value'/'by_percent'：具体值主动约束/百分比主动约束
-    :param factor_exposure_lower_boundary: float/Series，风格因子暴露下限，默认为0
-    :param factor_exposure_upper_boundary: float/Series，风格因子暴露上限，默认为0
-    :param sector_exposure_lower_boundary: float/Series，行业因子暴露下限，默认为0
-    :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为0
+    :param factor_exposure_lower_boundary: float/Series，风格因子暴露下限，默认为-10
+    :param factor_exposure_upper_boundary: float/Series，风格因子暴露上限，默认为10
+    :param sector_exposure_lower_boundary: float/Series，行业因子暴露下限，默认为-10
+    :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为10
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
+    :param cash_boundary: list of float, 现金约束,默认[0.0,0.0],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
     :return: dict
     """
+    if soft_params is None:
+        soft_params = pd.DataFrame()
+    if cash_boundary is None:
+        cash_boundary = [0.0, 0.0]
     if not print_validate_factor_frame(factor_frame):
         return
+
+    tickers = factor_frame.columns.values
+    if len(tickers[0]) > 6:
+        tickers_new = [ticker[:6] for ticker in tickers]
+        factor_frame.columns = tickers_new
+
     # 宽格式转换为长格式
     factor_value_frame = factor_frame.copy()
     factor_value_frame.index.name = 'date'
     factor_value_frame.reset_index(inplace=True)
     factor_value_frame = pd.melt(factor_value_frame, id_vars=['date'], var_name='ticker', value_name='value')
-    if asset_cons_method not in ['absolute','active']:
+    factor_value_frame['date'] = factor_value_frame['date'].apply(lambda x: x.replace('-', ''))
+    if asset_cons_method not in ['absolute', 'active']:
         raise Exception('asset_cons_method not in ["absolute","active"]')
-    if asset_cons_type not in ['by_value','by_percent']:
+    if asset_cons_type not in ['by_value', 'by_percent']:
         raise Exception('asset_cons_type not in ["by_value","by_percent"]')
 
     result = portfolio_construction(
@@ -278,6 +310,7 @@ def limit_active_risk(
         sector_exposure_upper_boundary=sector_exposure_upper_boundary,
         risk_aversion=risk_aversion,
         soft_params=soft_params,
+        cash_boundary=cash_boundary
     )
     if result:
         result = {
@@ -292,9 +325,9 @@ def limit_portfolio_risk(
         target_risk=0.3, target_turnover=None, fee=0, init_cash=1e8, init_holding=None,
         asset_lower_boundary=0, asset_upper_boundary=1,
         asset_cons_method='absolute', asset_cons_type='by_value',
-        factor_exposure_lower_boundary=0, factor_exposure_upper_boundary=0,
-        sector_exposure_lower_boundary=0, sector_exposure_upper_boundary=0,
-        risk_aversion=0, soft_params=pd.DataFrame()
+        factor_exposure_lower_boundary=-10, factor_exposure_upper_boundary=10,
+        sector_exposure_lower_boundary=-10, sector_exposure_upper_boundary=10,
+        risk_aversion=0, soft_params=None, cash_boundary=None
 ):
     """
     :param factor_frame:
@@ -317,24 +350,37 @@ def limit_portfolio_risk(
     :param asset_upper_boundary: float/Series，个股仓位上限，默认为1
     :param asset_cons_method: str， 资产上下界约束方法，支持选择'absolute'/'active'：绝对权重约束/主动权重约束
     :param asset_cons_type: str， 资产主动权重约束类型，支持选择'by_value'/'by_percent'：具体值主动约束/百分比主动约束
-    :param factor_exposure_lower_boundary: float/Series，风格因子暴露下限，默认为0
-    :param factor_exposure_upper_boundary: float/Series，风格因子暴露上限，默认为0
-    :param sector_exposure_lower_boundary: float/Series，行业因子暴露下限，默认为0
-    :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为0
+    :param factor_exposure_lower_boundary: float/Series，风格因子暴露下限，默认为-10
+    :param factor_exposure_upper_boundary: float/Series，风格因子暴露上限，默认为10
+    :param sector_exposure_lower_boundary: float/Series，行业因子暴露下限，默认为-10
+    :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为10
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
+    :param cash_boundary: list of float, 现金约束,默认[0.0,0.0],即默认为满仓约束,如果传[0.05,0.1],说明现金约束在5%～10%之间
     :return: dict
     """
+    if soft_params is None:
+        soft_params = pd.DataFrame()
+    if cash_boundary is None:
+        cash_boundary = [0.0, 0.0]
     if not print_validate_factor_frame(factor_frame):
         return
+
+    tickers = factor_frame.columns.values
+    if len(tickers[0]) > 6:
+        tickers_new = [ticker[:6] for ticker in tickers]
+        factor_frame.columns = tickers_new
+
     # 宽格式转换为长格式
     factor_value_frame = factor_frame.copy()
     factor_value_frame.index.name = 'date'
     factor_value_frame.reset_index(inplace=True)
     factor_value_frame = pd.melt(factor_value_frame, id_vars=['date'], var_name='ticker', value_name='value')
-    if asset_cons_method not in ['absolute','active']:
+    factor_value_frame['date'] = factor_value_frame['date'].apply(lambda x: x.replace('-', ''))
+
+    if asset_cons_method not in ['absolute', 'active']:
         raise Exception('asset_cons_method not in ["absolute","active"]')
-    if asset_cons_type not in ['by_value','by_percent']:
+    if asset_cons_type not in ['by_value', 'by_percent']:
         raise Exception('asset_cons_type not in ["by_value","by_percent"]')
 
     result = portfolio_construction(
@@ -361,6 +407,7 @@ def limit_portfolio_risk(
         sector_exposure_upper_boundary=sector_exposure_upper_boundary,
         risk_aversion=risk_aversion,
         soft_params=soft_params,
+        cash_boundary=cash_boundary
     )
     if result:
         result = {
