@@ -54,16 +54,31 @@ def _get_task_result(url, api, post_data):
     return format_res['task_result']
 
 
+def ticker_to_secid(ticker):
+    sec_id = ticker + ('.XSHE' if ticker[0] in '30' else '.XSHG')
+    return sec_id
+
+
+def tickers_to_secids(tickers):
+    sec_ids = [ticker + ('.XSHE' if ticker[0] in '30' else '.XSHG') for ticker in tickers]
+    return sec_ids
+
+
+def secids_to_tickers(secids):
+    sec_ids = [secid[:6] for secid in secids]
+    return sec_ids
+
+
 # 不带回测的construction
 def portfolio_construction(factor_value_frame, construct_method, start_date, end_date, frequency, construct_type='end',
                            simulate=False, universe='HS300', benchmark='HS300', top_ratio=0.2, down_ratio=0.2,
                            select_type=1, weight_type='equal', is_factor_constrained=True, target_risk=0.3,
                            target_turnover=None, fee=0, init_cash=1e8, init_holding=None, asset_lower_boundary=0,
                            asset_upper_boundary=1, asset_cons_method='absolute', asset_cons_type='by_value',
-                           asset_group_lower_boundary={}, asset_group_upper_boundary={},
-                           factor_exposure_lower_boundary=0, factor_exposure_upper_boundary=0,
-                           sector_exposure_lower_boundary=0, sector_exposure_upper_boundary=0,
-                           risk_aversion=0, soft_params=pd.DataFrame(), **kwargs):
+                           asset_group_lower_boundary=None, asset_group_upper_boundary=None,
+                           factor_exposure_lower_boundary=-10, factor_exposure_upper_boundary=10,
+                           sector_exposure_lower_boundary=-10, sector_exposure_upper_boundary=10,
+                           risk_aversion=0, soft_params=None, **kwargs):
     """
     :param factor_value_frame:DataFrame of factor value，因子数据，
                     需包含三列: date(str), ticker(str), value(float)
@@ -93,16 +108,30 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
     :param asset_upper_boundary: float/Series，个股仓位上限，默认为1
     :param asset_cons_method: 资产权重上下界约束方法，'absolute'：绝对权重约束；'active'：主动权重约束
     :param asset_cons_type: 资产主动权重约束类型，'by_value'：具体值主动约束；'by_percent'：百分比主动约束
-    :param factor_exposure_lower_boundary: float/Series，风格因子暴露下限，默认为0
-    :param factor_exposure_upper_boundary: float/Series，风格因子暴露上限，默认为0
-    :param sector_exposure_lower_boundary: float/Series，行业因子暴露下限，默认为0
-    :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为0
+    :param factor_exposure_lower_boundary: float/Series，风格因子暴露下限，默认为-10
+    :param factor_exposure_upper_boundary: float/Series，风格因子暴露上限，默认为10
+    :param sector_exposure_lower_boundary: float/Series，行业因子暴露下限，默认为-10
+    :param sector_exposure_upper_boundary: float/Series，行业因子暴露上限，默认为10
     :param asset_group_lower_boundary: 分组资产权重总和约束下界, dict, key为调仓日期，value为list of Series
     :param asset_group_upper_boundary: 分组资产权重总和约束上界, dict, key为调仓日期，value为list of Series
     :param risk_aversion: float,风险厌恶系数, >= 0，如果不传则默认为0
     :param soft_params: pd.DataFrame, 软约束参数
     :return: dict
     """
+    if asset_group_lower_boundary is None:
+        asset_group_lower_boundary = {}
+    if asset_group_upper_boundary is None:
+        asset_group_upper_boundary = {}
+    if soft_params is None:
+        soft_params = pd.DataFrame()
+    price_type = kwargs.get('price_type', 'open')
+    risk_model_type = kwargs.get('risk_model_type')
+    cash_boundary = kwargs.get('cash_boundary', [0.0, 0.0])
+    if type(cash_boundary) is not list or len(cash_boundary) != 2 or type(cash_boundary[0]) not in [int,
+                                                                                                      float] or type(
+            cash_boundary[1]) not in [int, float]:
+        print('cash_boundary只能为包含两个float类型数据的list')
+        return
     if end_date < start_date:
         print("end_date应当大于start_date,请校验后重新输入")
         return
@@ -140,7 +169,7 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
     sector_exposure_upper_boundary = sector_exposure_upper_boundary.to_json() \
         if isinstance(sector_exposure_upper_boundary, pd.Series) \
         else sector_exposure_upper_boundary
-    soft_params = soft_params.to_json() if not soft_params.empty else {}
+    soft_params = soft_params.to_dict() if not soft_params.empty else {}
     if init_holding is not None:
         init_holding = init_holding.to_dict() if isinstance(
             init_holding, pd.Series) else init_holding
@@ -148,9 +177,11 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
                                             for k, v in asset_group_lower_boundary.items()}
     asset_group_upper_boundary_list_dict = {k: [g.to_json() for g in v]
                                             for k, v in asset_group_upper_boundary.items()}
-    price_type = kwargs.get('price_type', 'open')
-    risk_model_type = kwargs.get('risk_model_type')
-    opt_params = kwargs.get('opt_params', dict())
+    opt_params = {
+        'set_soft': True if soft_params else False,
+        'soft_params': soft_params,
+        'risk_aversion': risk_aversion
+    }
 
     if isinstance(benchmark, dict):
         benchmark_values = list(benchmark.values())
@@ -165,6 +196,25 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
         else:
             benchmark = benchmark
 
+    if isinstance(universe, dict):
+        if len(list(universe.values())[0][0]) == 6:
+            universe = {k: tickers_to_secids(v) for k, v in universe.items()}
+
+    if isinstance(benchmark, dict):
+        if len(list(list(benchmark.values())[0].keys())[0]) > 6:
+            benchmark = {k: {_k[:6]: _v for _k, _v in v.items()} for k, v in benchmark.items()}
+
+    # 兼容python2和python3的判断是否是字符串
+    if type(asset_lower_boundary) in (type(u''), type(b'')):
+        if len(list(json.loads(asset_lower_boundary).keys())[0]) == 6:
+            asset_lower_boundary = {ticker_to_secid(k): v for k, v in json.loads(asset_lower_boundary).items()}
+            asset_lower_boundary = json.dumps(asset_lower_boundary)
+
+    if type(asset_upper_boundary) in (type(u''), type(b'')):
+        if len(list(json.loads(asset_upper_boundary).keys())[0]) == 6:
+            asset_upper_boundary = {ticker_to_secid(k): v for k, v in json.loads(asset_lower_boundary).items()}
+            asset_upper_boundary = json.dumps(asset_upper_boundary)
+
     construct_data = {
         "a_signal": alpha_signals,
         "construct_method": construct_method,
@@ -191,8 +241,7 @@ def portfolio_construction(factor_value_frame, construct_method, start_date, end
         'opt_params': opt_params,
         "asset_group_lower_boundary_list_dict": asset_group_lower_boundary_list_dict,
         "asset_group_upper_boundary_list_dict": asset_group_upper_boundary_list_dict,
-        "risk_aversion": risk_aversion,
-        "soft_params": soft_params,
+        "cash_boundary": cash_boundary
     }
     try:
         # print('正在进行组合构建分析，花费的时长受股票数量和分析区间的影响，请稍等...')
